Stan Math Library: stan/math/fwd/mat/fun/Eigen_NumTraits.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
Eigen_NumTraits.hpp File Reference
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <limits>`

Go to the source code of this file.

## Classes
struct | Eigen::NumTraits< stan::math::fvar< T > >
| Numerical traits template override for Eigen for automatic gradient variables. More...
struct | Eigen::internal::significant_decimals_default_impl< stan::math::fvar< T >, false >
| Implemented this for printing to stream. More...

## Namespaces
| Eigen
| (Expert) Numerical traits for algorithmic differentiation variables.
| Eigen::internal
| (Expert) Product traits for algorithmic differentiation variables.

[ Stan Home Page ] © 2011–2016, Stan Development Team.